@@ -55,7 +55,7 @@ AboutDialog::AboutDialog( QWidget *parent)
     "  <ul>"
     "    <li>Spanish: <a href=\"http://ieee.udistrital.edu.co/aclibre\">"
     "                 ACLibre (Academia y Conocimiento Libre)</a> and David Amian</li>"
-    "    <li>French: Philippe Caillaud and Claude </li>"
+    "    <li>French: Marc Sert, Philippe Caillaud and Claude </li>"
     "    <li>Italian: Giovanni Sora, Seyed Puria Nafisi Azizi </li>"
     "    <li>Interlingua: Giovanni Sora</li>"
     "    <li>Brasilian: Amadeu Júnior</li>"
@@ -68,6 +68,7 @@ AboutDialog::AboutDialog( QWidget *parent)
     "  <ul>"
     "    <li>Konstantin Goudkov: sort branches</li>"
     "    <li>Jakob Hilmer: image drag and drop in 1.8.1, &quot;About vym&quot; window patch </li>"
+    "    <li>Edward Wang: adding close tab buttons</li>"
     "  </ul>"
     "</li>"
     "<li> Patches in previous vym versions"
@@ -89,7 +90,7 @@ AboutDialog::AboutDialog( QWidget *parent)
     "<li> General"
     "  <ul>"
     "    <li>CMake setup by Costantino Giuliodori and Patrick Spendrin</li>"
-    "    <li>All the guys at Trolltech (now Nokia) for their Qt toolkit</li>"
+    "    <li>All the guys at Trolltech (now Digia) for their Qt toolkit</li>"
     "    <li>All the guys at SUSE Linux for openSUSE Linux and support,"
     "        e.g. to get Linux running on PowerPC and also Macbooks</li>"
     "  </ul>"
