@@ -3,6 +3,7 @@
 #include <QtCore/QString>
 #include <QtCore/QVariant>
 
+#include "branchitem.h"
 #include "mainwindow.h"
 #include "vymmodel.h"
 
@@ -16,11 +17,6 @@ AdaptorModel::AdaptorModel(QObject *obj)
     setAutoRelaySignals (true);
 }
 
-AdaptorModel::~AdaptorModel()
-{
-    // destructor
-}
-
 void AdaptorModel::setModel(VymModel *vm)
 {
     model=vm;
@@ -36,17 +32,6 @@ void AdaptorModel::setCaption (const QString &newCaption)
     m_caption=newCaption;
 }
 
-QDBusVariant AdaptorModel::query(const QString &)
-{
-    QString s;
-    if (model)
-    s=model->getHeading();
-    else
-    s="oops, no vymModel?";
-
-    return QDBusVariant (s);
-}
-
 QDBusVariant AdaptorModel::getCurrentModelID()
 {
     return QDBusVariant (mainWindow->currentModelID());
@@ -56,29 +41,44 @@ QDBusVariant AdaptorModel::getHeading()
 {
     QString s;
     if (model)
-    s=model->getHeading();
+	s=model->getHeading();
     else
-    s="oops, no vymModel?";
+	s="oops, no vymModel?";
 
     return QDBusVariant (s);
 }
 
-
 void AdaptorModel::setHeading (const QString &s)
 {
-    model->setHeading(s);
+    if (model) model->setHeading(s);
 }
 
-QDBusVariant AdaptorModel::getInstanceName()
+QDBusVariant AdaptorModel::branchCount()
 {
-    return QDBusVariant (vymInstanceName);
+    BranchItem *selbi=model->getSelectedBranch();
+    if (selbi) 
+	return QDBusVariant (selbi->branchCount() );
+    else	
+	return QDBusVariant (-1 );
 }
 
 QDBusVariant AdaptorModel::execute (const QString &s)
 {
-    if (model)
-    return QDBusVariant (model->runScript (s));
-    else
-    return QDBusVariant ("No model.");
+    return QDBusVariant (model->execute (s));
+}
+
+QDBusVariant AdaptorModel::errorLevel()
+{
+    return QDBusVariant (model->parser.errorLevel() );
+}
+
+QDBusVariant AdaptorModel::errorDescription()
+{
+    return QDBusVariant (model->parser.errorDescription() );
+}
+
+QDBusVariant AdaptorModel::listCommands ()
+{
+    return QDBusVariant (model->parser.getCommands().join(",") );
 }
 
