@@ -46,7 +46,7 @@ BranchObj::~BranchObj ()
 
 void BranchObj::init () 
 {
-    if (parObj) absPos=parObj->getChildPos();
+    if (parObj) absPos=parObj->getChildRefPos();
 }
 
 void BranchObj::copy (BranchObj* other)
@@ -95,7 +95,7 @@ void BranchObj::setParObjTmp(LinkableMapObj* dst, QPointF m, int off)
     // Better just do it approximately
     if (dsti->depth()==0)   
     {	// new parent is a mapcenter
-	Vector v= ( m - bodst->getChildPos());
+	Vector v= ( m - bodst->getChildRefPos());
 	v.normalize();
 	v.scale (150);
 	move2RelPos (v.toQPointF());
@@ -129,12 +129,12 @@ void BranchObj::setParObjTmp(LinkableMapObj* dst, QPointF m, int off)
 		// Bottom of sel should be 5 pixels above
 		// the bottom of the branch _below_ the target:
 		// Don't try to find that branch, guess 12 pixels
-		y=bodst->getChildPos().y()  -height() + 12; 
+		y=bodst->getChildRefPos().y()  -height() + 12; 
 	}   
 	if (bodst->getOrientation()==LinkableMapObj::LeftOfCenter)
-	    move ( bodst->getChildPos().x() - linkwidth, y );
+	    move ( bodst->getChildRefPos().x() - linkwidth, y );
 	else	
-	    move (bodst->getChildPos().x() + linkwidth, y );
+	    move (bodst->getChildRefPos().x() + linkwidth, y );
     }	
 
     // updateLinkGeometry is called implicitly in move
@@ -202,26 +202,18 @@ void BranchObj::setLinkColor ()
     }	    
 }
 
-void BranchObj::updateContentSize()
-{
-    if (debug) qDebug()<<"BO::updateContentSize"; // FIXME-8
-    calcBBoxSize();
-    positionBBox();
-    requestReposition();
-}
-
 void BranchObj::positionContents()
 {
-    if (debug) qDebug()<<"  BO::positionContents (loop over images)";   //FIXME-8
+    if (debug) qDebug()<<"  BO::positionContents (loop over images): "<<treeItem->getHeading()<<treeItem->imageCount();   //FIXME-8
+    OrnamentedObj::positionContents();
+    updateLinkGeometry();// required before positioning images
     for (int i=0; i<treeItem->imageCount(); ++i)
 	treeItem->getImageObjNum(i)->reposition();
-    OrnamentedObj::positionContents();
 }
 
 void BranchObj::move (double x, double y)
 {
     OrnamentedObj::move (x,y);
-    positionBBox();
 }
 
 void BranchObj::move (QPointF p)
@@ -244,11 +236,10 @@ void BranchObj::moveBy (QPointF p)
 
 void BranchObj::positionBBox() // FIXME-2 consider dimensions of frame (thickness, geometry, padding...
 {
-    //FIXME-8 
-    if (debug) qDebug()<<"  BO::positionBBox ("<<treeItem->getHeading()<<")";
+    if (debug) qDebug()<<"        BO::positionBBox ("<<treeItem->getHeading()<<")"; //FIXME-8 
     QPointF ap=getAbsPos();
     bbox.moveTopLeft (ap);
-    positionContents();
+    positionContents();   // this positions FIOs  
 
     //Update links to other branches	
     XLinkObj *xlo;
@@ -261,8 +252,7 @@ void BranchObj::positionBBox() // FIXME-2 consider dimensions of frame (thicknes
 
 void BranchObj::calcBBoxSize()
 {
-    //FIXME-8 
-    if (debug) qDebug()<<"  BO::calcBBoxSize ("<<treeItem->getHeading()<<")";
+    if (debug) qDebug()<<"**BO::calcBBoxSize ("<<treeItem->getHeading()<<")"; //FIXME-8 
     QSizeF heading_r=heading->getSize();
     qreal heading_w=(qreal) heading_r.width() ;
     qreal heading_h=(qreal) heading_r.height() ;
@@ -301,28 +291,32 @@ void BranchObj::calcBBoxSize()
 	{
 	    fio=treeItem->getImageObjNum(i);
 	    rp=fio->getRelPos();
+            if (debug) qDebug()<<"**BO::calcBBoxSize rp="<<rp<<"fio (h,w)=("<<fio->width()<<","<<fio->height()<<")"; // FIXME-8
 	    if (incV)
 	    {
-		if (rp.y() < 0) 
-		    topPad=max (topPad,-rp.y()-h);
-		if (rp.y()+fio->height() > 0)
-		    botPad=max (botPad,rp.y()+fio->height());
+                qreal y;
+                if (rp.y() > 0)
+                {
+                    y=rp.y() + fio->height()/2 - ornamentsBBox.height()/2;
+                    botPad=max(botPad, y);
+                } else
+                {
+                    y=-rp.y() + fio->height()/2 - ornamentsBBox.height()/2;
+                    topPad=max(topPad, y);
+                }
 	    }	    
 	    if (incH)
 	    {
-		if (orientation==LinkableMapObj::RightOfCenter)
-		{
-		    if (-rp.x()-w > 0) 
-			leftPad=max (leftPad,-rp.x()-w);
-		    if (rp.x()+fio->width() > 0)
-			rightPad=max (rightPad,rp.x()+fio->width());
-		} else
-		{
-		    if (rp.x()< 0) 
-			leftPad=max (leftPad,-rp.x());
-		    if (rp.x()+fio->width() > w)
-			rightPad=max (rightPad,rp.x()+fio->width()-w);
-		}
+                qreal x;
+                if (rp.x() > 0)
+                {
+                    x=rp.x() + fio->width()/2 - ornamentsBBox.width()/2;
+                    rightPad=max(rightPad, x);
+                } else
+                {
+                    x=-rp.x() + fio->width()/2 - ornamentsBBox.width()/2;
+                    leftPad=max(leftPad, x);
+                }
 	    }	    
 	}   
 	h+=topPad+botPad;
@@ -330,8 +324,8 @@ void BranchObj::calcBBoxSize()
     }
 
     // Frame thickness  
-    w+=(frame->getBorderWidth() + frame->getPadding() ) * 2;
-    h+=(frame->getBorderWidth() + frame->getPadding() ) * 2;
+    w += frame->getTotalPadding() * 2;
+    h += frame->getTotalPadding() * 2;
     
     // Finally set size
     bbox.setSize (QSizeF (w,h));
@@ -340,13 +334,15 @@ void BranchObj::calcBBoxSize()
 
 void BranchObj::setDockPos()
 {
+    floatRefPos=ornamentsBBox.center();
+
     if (treeItem->getType()==TreeItem::MapCenter)
     {
-	// set childPos to middle of MapCenterObj
+	// set childRefPos to middle of MapCenterObj
 	QRectF r=clickPoly.boundingRect();
-	childPos.setX( r.topLeft().x() + r.width()/2 );
-	childPos.setY( r.topLeft().y() + r.height()/2 );
-	parPos=childPos;	
+	childRefPos.setX( r.topLeft().x() + r.width()/2 );
+	childRefPos.setY( r.topLeft().y() + r.height()/2 );
+	parPos=childRefPos;	
 	for (int i=0; i<treeItem->branchCount(); ++i)
 	    treeItem->getBranchObjNum(i)->updateLinkGeometry();
 
@@ -354,24 +350,26 @@ void BranchObj::setDockPos()
     {
 	if (orientation==LinkableMapObj::LeftOfCenter )
 	{
+            // Left of center
 	    if ( ((BranchItem*)treeItem)->getFrameIncludeChildren() )
 	    {
-		childPos=QPointF (ornamentsBBox.bottomLeft().x(),  bottomlineY);
+		childRefPos=QPointF (ornamentsBBox.bottomLeft().x() - leftPad,  bottomlineY);
 		parPos=QPointF   (bboxTotal.bottomRight().x()-frame->getPadding()/2, bottomlineY);
 	    } else	
 	    {
-		childPos=QPointF (ornamentsBBox.bottomLeft().x()-frame->getPadding(),  bottomlineY);
+		childRefPos=QPointF (ornamentsBBox.bottomLeft().x() - frame->getPadding(),  bottomlineY);
 		parPos=QPointF   (ornamentsBBox.bottomRight().x(), bottomlineY);
 	    }
 	} else
 	{
+            // Right of center
 	    if ( ((BranchItem*)treeItem)->getFrameIncludeChildren() )
 	    {
-		childPos=QPointF(ornamentsBBox.bottomRight().x(), bottomlineY);
+		childRefPos=QPointF(ornamentsBBox.bottomRight().x() + rightPad , bottomlineY);
 		parPos=QPointF ( bboxTotal.bottomLeft().x()+frame->getPadding()/2,  bottomlineY);
 	    } else	
 	    {
-		childPos=QPointF(ornamentsBBox.bottomRight().x()+ frame->getPadding(), bottomlineY);
+		childRefPos=QPointF(ornamentsBBox.bottomRight().x() + frame->getPadding(), bottomlineY);
 		parPos=QPointF ( ornamentsBBox.bottomLeft().x(),  bottomlineY);
 	    }
 	}
@@ -380,19 +378,14 @@ void BranchObj::setDockPos()
 
 void BranchObj::updateData()
 {
-    bool changed=false;
     if (!treeItem)
     {
 	qWarning ("BranchObj::udpateHeading treeItem==NULL");
 	return;
     }
-    if (debug) qDebug()<<"BO::updateData  "<<treeItem->getHeadingDepth(); //FIXME-8
     QString s=treeItem->getHeading();
-    if (s!=heading->text())
-    {
-	heading->setText (s);
-	changed=true;
-    }
+    if (s!=heading->text()) heading->setText (s);
+
     QStringList TIactiveFlags=treeItem->activeStandardFlagNames();
 
     // Add missing standard flags active in TreeItem
@@ -402,17 +395,13 @@ void BranchObj::updateData()
 	{
 	    Flag *f=standardFlagsMaster->getFlag(TIactiveFlags.at(i));
 	    if (f) standardFlags->activate (f);
-	    changed=true;
 	}
     }
     // Remove standard flags no longer active in TreeItem
     QStringList BOactiveFlags=standardFlags->activeFlagNames();
     for (int i=0;i<BOactiveFlags.size();++i)
 	if (!TIactiveFlags.contains (BOactiveFlags.at(i)))
-	{
 	    standardFlags->deactivate (BOactiveFlags.at(i));
-	    changed=true;
-	}   
 
     // Add missing system flags active in TreeItem
     TIactiveFlags=treeItem->activeSystemFlagNames();
@@ -422,7 +411,6 @@ void BranchObj::updateData()
 	{
 	    Flag *f=systemFlagsMaster->getFlag(TIactiveFlags.at(i));
 	    if (f) systemFlags->activate (f);
-	    changed=true;
 	}
     }
     // Remove system flags no longer active in TreeItem
@@ -430,12 +418,10 @@ void BranchObj::updateData()
     for (int i=0;i<BOactiveFlags.size();++i)
     {
 	if (!TIactiveFlags.contains (BOactiveFlags.at(i)))
-	{
 	    systemFlags->deactivate (BOactiveFlags.at(i));
-	    changed=true;
-	}   
     }
-    if (changed) updateContentSize(); 
+    if (debug) qDebug()<<"BO::updateData  "<<treeItem->getHeadingDepth(); // FIXME-8
+    calcBBoxSize(); 
 }
 
 void BranchObj::setDefAttr (BranchModification mod, bool keepFrame)
@@ -485,56 +471,65 @@ void BranchObj::setDefAttr (BranchModification mod, bool keepFrame)
 
 void BranchObj::alignRelativeTo (QPointF ref,bool alignSelf)
 {
+    // Define some heights
     qreal th = bboxTotal.height();  
+    qreal ch=0; // Sum of childrens heights
+    for (int i=0; i<treeItem->branchCount(); ++i)
+        ch+=treeItem->getBranchObjNum(i)->getTotalBBox().height();
+
     int depth=0;
     if (parObj)	depth=1 + parObj->getTreeItem()->depth();
+    
 // TODO testing
 /*
-if (debug)
-{
-    QString o;
-    switch (orientation)
-    {	
-	case UndefinedOrientation: o="UndefOrientation";
-	case LeftOfCenter: o="LeftOfCenter";
-	case RightOfCenter: o="RightOfCenter";
+    if (debug)
+    {
+        QString o;
+        switch (orientation)
+        {	
+            case UndefinedOrientation: o="UndefOrientation";
+            case LeftOfCenter: o="LeftOfCenter";
+            case RightOfCenter: o="RightOfCenter";
+        }
+            
+        QString h=QString (depth+1,' ');
+        h+=treeItem->getHeading();
+        h+=QString (15,' ');
+        h.truncate (15);
+        QPointF pp; 
+        if (parObj) pp=parObj->getChildRefPos();
+        qDebug() << "BO::alignRelTo for "<<h;
+        qDebug() << "    d="<<depth;
+    //    qDebug() <<"   ref="<<ref;
+    //    qDebug() <<"    th="<<th;
+    //    qDebug() <<"    ch="<<ch;
+        if (ch < th) qDebug()<<"   ch<th !";
+    //    qDebug() <<"  parO="<<parObj;
+        //qDebug() <<   "  bbox.tL="<<bboxTotal.topLeft();
+    //    qDebug() <<"absPos="<<absPos
+    //	<< "  relPos="<<relPos
+    //	<< "  parPos="<<pp
+    //	<< "  bbox="<<bbox
+    //	<< "  orient="<<o<<" "<<orientation;
+    //	<< "  alignSelf="<<alignSelf
+    //	<< "  scrolled="<<((BranchItem*)treeItem)->isScrolled()
+    //	<< "  pad="<<topPad<<","<<botPad<<","<<leftPad<<","<<rightPad
+    //	<< "  hidden="<<hidden
+    //	<< "  th="<<th
+        ;
     }
-	
-    QString h=QString (depth+1,' ');
-    h+=treeItem->getHeading();
-    h+=QString (15,' ');
-    h.truncate (15);
-    QPointF pp; 
-    if (parObj) pp=parObj->getChildPos();
-    qDebug() << "BO::alignRelTo for "<<h;
-//    qDebug() << "    d="<<depth;
-//    qDebug() <<"  parO="<<parObj;
-//    qDebug() <<"   ref="<<ref;
-    //qDebug() <<   "  bbox.tL="<<bboxTotal.topLeft();
-//    qDebug() <<"absPos="<<absPos
-//	<< "  relPos="<<relPos
-//	<< "  parPos="<<pp
-//	<< "  bbox="<<bbox
-//	<< "  orient="<<o<<" "<<orientation;
-//	<< "  alignSelf="<<alignSelf
-//	<< "  scrolled="<<((BranchItem*)treeItem)->isScrolled()
-//	<< "  pad="<<topPad<<","<<botPad<<","<<leftPad<<","<<rightPad
-//	<< "  hidden="<<hidden
-//	<< "  th="<<th
-    ;
-}
 */
 
-    setOrientation();
-    //updateLinkGeometry();
 
-    if (depth==1)
+    setOrientation();
+
+    // Align myself
+    if (depth==0)
+        move (getAbsPos()); // Trigger update of frames etc.
+    else if(depth==1)
 	move2RelPos (getRelPos() );
     else if (depth>1)
     {
-	// Align myself depending on orientation and parent, but
-	// only if I am not a mainbranch or mapcenter itself
-
 	if (anim.isAnimated())
 	    move2RelPos(anim);
 	else
@@ -546,7 +541,8 @@ if (debug)
 			move (ref.x() - bbox.width(), ref.y() + (th-bbox.height())/2 );
 		    break;
 		    case LinkableMapObj::RightOfCenter:	
-			move (ref.x() , ref.y() + (th-bbox.height())/2  );
+			move (ref.x() , ref.y() + (th - bbox.height())/2 );
+			//move (ref.x() , ref.y() );
 		    break;
 		    default:
 			qWarning ("LMO::alignRelativeTo: oops, no orientation given for BO...");
@@ -555,34 +551,27 @@ if (debug)
 	}
     }	    
 
+    // Without ancestors I am done
     if ( ((BranchItem*)treeItem)->isScrolled() ) return;
 
     // Set reference point for alignment of children
     QPointF ref2;
     if (orientation==LinkableMapObj::LeftOfCenter)
-	ref2.setX(childPos.x() - linkwidth);
+	ref2.setX(childRefPos.x() - linkwidth);
     else    
-	ref2.setX(childPos.x() + linkwidth);
+	ref2.setX(childRefPos.x() + linkwidth);
 
     if (depth==1)
-	ref2.setY(absPos.y()-(bboxTotal.height()-bbox.height())/2 + frame->getPadding() );
+	ref2.setY (absPos.y() + (bbox.height() - ch)/2);
     else    
-	ref2.setY (ref.y() + frame->getPadding());  
-
-    // Align the attribute children depending on reference point 
-    // on top like in TreeEditor
-    for (int i=0; i<treeItem->attributeCount(); ++i)
-    {	
-	if (!treeItem->getAttributeNum(i)->isHidden())
-	{
-	    BranchObj *bo=(BranchObj*)(treeItem->getAttributeNum(i)->getBranchObj());
-	    if (!bo) break;
-	    bo->alignRelativeTo (ref2,true);
-
-	    // append next branch below current one
-	    ref2.setY(ref2.y() + bo->getTotalBBox().height() );
-	}
+    {
+        if (ch > th)
+            ref2.setY (ref.y() + frame->getPadding());  
+        else
+            // Parent is bigger than all of childs, center childs vertically
+            ref2.setY (ref.y() + (th - ch)/2 );
     }
+
     // Align the branch children depending on reference point 
     for (int i=0; i<treeItem->branchCount(); ++i)
     {	
@@ -596,39 +585,26 @@ if (debug)
     }
 }
 
-
 void BranchObj::reposition()
 {   
 /* TODO testing only
-*/	
-    if (debug)  //FIXME-8
+    if (debug) 
     {
-    if (!treeItem->getHeading().isEmpty())
-	qDebug()<< "BO::reposition  a) "<<treeItem->depth()<<" "<<treeItem->getHeading();
-    else    
-	qDebug()<< "BO::reposition  a) ???";
+        if (!treeItem->getHeading().isEmpty())
+            qDebug()<< "  BO::reposition  a) d="<<treeItem->depth()<<" "<<treeItem->getHeading();
+        else    
+            qDebug()<< "  BO::reposition  a) d="<<treeItem->depth()<<" ???";
     }
+*/	
 
     if (treeItem->depth()==0)
-    {
 	// only calculate the sizes once. If the deepest LMO 
 	// changes its height,
 	// all upper LMOs have to change, too.
-	calcBBoxSizeWithChildren();
-	updateLinkGeometry();	// This update is needed if the scene is resized 
-			// due to excessive moving of a FIO
+	calcBBoxSizeWithChildren(); 
 
-	alignRelativeTo ( QPointF (absPos.x(),
-	    absPos.y()-(bboxTotal.height()-bbox.height())/2) );	
-	    //absPos.y() ) );
-	positionBBox();	// Reposition bbox and contents
-    } else
-    {
-	// This is only important for moving branches:
-	// For editing a branch it isn't called...
-	alignRelativeTo ( QPointF (absPos.x(),
-			    absPos.y()-(bboxTotal.height()-bbox.height())/2) );	
-    }
+    alignRelativeTo ( QPointF (absPos.x(),
+        absPos.y()-(bboxTotal.height()-bbox.height())/2) );	
 }
 
 void BranchObj::unsetAllRepositionRequests()
@@ -663,17 +639,8 @@ ConvexPolygon BranchObj::getBoundingPolygon()
 
 void BranchObj::calcBBoxSizeWithChildren()  
 {   
-    // FIXME-1 Below is wrong. Called multiple times!
-    // FIXME-2 Hm, should not be necessary at all???
-    
-    // This is initially called only from reposition and
-    // and only for mapcenter. So it won't be
-    // called more than once for a single user 
-    // action
-
     // if branch is scrolled, ignore children, but still consider floatimages
     BranchItem *bi=(BranchItem*)treeItem;
-    if (debug) qDebug()<<"BO::calcBBSizeWithChildren  "<<bi->getHeadingDepth(); //FIXME-8
     if ( bi->isScrolled() ) 
     {
 	bboxTotal.setWidth (bbox.width());
@@ -688,11 +655,10 @@ void BranchObj::calcBBoxSizeWithChildren()
 	return;
     }
     
-    /* FIXME-2 not really needed?
-    */
     QRectF r(0,0,0,0);
     QRectF br;
-    // Now calculate recursivly
+
+    // Now calculate 
     // sum of heights 
     // maximum of widths 
     // minimum of y
@@ -744,10 +710,6 @@ bool BranchObj::animate()
 	    move (anim);
 	return true;
     }
-    /*FIXME-3 reposition in BO:animate nearly never reached? needed?	
-    if (((MapItem*)treeItem)->getPositionMode()==MapItem::Relative)
-	parObj->reposition();	// we might have been relinked meanwhile
-    */	
     return false;
 }
 
