@@ -8,20 +8,35 @@
 extern Settings settings;
 extern QDir vymBaseDir;
 
-QString Macros::getPath ()
+QString Macros::getBasePath ()
 {
     return settings.value ("macros/macroDir",vymBaseDir.path()+"/macros").toString();
 }
 
 QString Macros::getPath (const int &i)
 {
-    return getPath() + QString("/macro-%1.vys").arg(i);
+    QString pad;
+    int n=i;
+    if (i%13 <10)
+        pad="0";
+    else
+        pad="";
+
+    QString prefix;
+    if (i<13) 
+        prefix="";
+    else
+    {
+        prefix="s";
+        n=i-12;
+    }
+    return getBasePath() + QString("/macro-%1%2%3.vys").arg(prefix).arg(pad).arg(n);
 }
 
 QString Macros::getMacro (const int &i)    
 {
 
-    QString fn=getPath(i+1);
+    QString fn=getPath(i);
     QFile f (fn);
     if ( !f.open( QIODevice::ReadOnly ) )
     {
