@@ -6,7 +6,10 @@
 #include <QPointF>
 #include <QTextCursor>
 
+#if defined(VYM_DBUS)
 #include "adaptormodel.h"
+#endif
+
 #include "file.h"
 #include "imageitem.h"
 #include "mapeditor.h"
@@ -530,6 +533,9 @@ public:
     /*! Export as ASCII text to file */
     void exportASCII (const QString &fname="",bool askForName=true);  
 
+    /*! Export as CSV text to file */
+    void exportCSV (const QString &fname="",bool askForName=true);  
+
     /*! Export as HTML to directory */
     void exportHTML(const QString &dir="", const QString &fname="", bool useDialog=true);    
 
@@ -549,6 +555,9 @@ public:
     /*! Export as LaTeX */
     void exportLaTeX (const QString& dir="", bool useDialog=true);    
 
+    /*! Export as OrgMode input for emacs*/
+    void exportOrgMode (const QString& fname="", bool useDialog=true);    
+
 ////////////////////////////////////////////
 // View related
 ////////////////////////////////////////////
