@@ -9,9 +9,7 @@ WarningDialog::WarningDialog(QWidget* parent):QDialog (parent)
     ui.setupUi(this);
     //TODO proper icon for proceed needed
     ui.okButton->setText(tr("Proceed"));
-    /*
-    ui.warningSign->setPixmap (QPixmap(iconPath + "icons/vym.png"));
-    */
+    // ui.warningSign->setPixmap (QPixmap(iconPath + "icons/vym.png"));
     ui.showAgainBox->setText (tr("Show this message again"));
     useShowAgain=false;
     ui.showAgainBox->hide();
@@ -22,14 +20,19 @@ int WarningDialog::exec()
     int result; 
     if (settings.value ("/warningDialog/"+showAgainName+"/showAgain",true).toBool()  )
     {
+	// Really show dialog
 	result=QDialog::exec();
 	if (result==QDialog::Accepted )
 	{
-	    settings.setValue ("/warningDialog/"+showAgainName+"/value",result);
-	    settings.setValue ("/warningDialog/"+showAgainName+"/showAgain",ui.showAgainBox->isChecked() );
+	    if (useShowAgain)
+	    {
+		settings.setValue ("/warningDialog/"+showAgainName+"/value",result);
+		settings.setValue ("/warningDialog/"+showAgainName+"/showAgain",ui.showAgainBox->isChecked() );
+	    }
 	}
     } else
     {
+	// Surpress dialog and use result from last shown dialog
 	result=settings.value ("/warningDialog/"+showAgainName+"/value",0).toInt();
     }
     return result;
