@@ -2,13 +2,12 @@
 #define XML_BASE
 
 
-#include <QString>
+//#include <QString>
 #include <QXmlAttributes>
 
 #include "file.h"
-#include "mapeditor.h"
-#include "vymmodel.h"
 
+class VymModel;
 
 /*! \brief Base class for parsing maps from XML documents */
 
@@ -30,6 +29,7 @@ public:
     void setTmpDir (QString);
     void setInputFile (QString);
     void setLoadMode (const LoadMode &,int p=-1);
+    bool readHtmlAttr    (const QXmlAttributes&);
 
 protected:
     QString     errorProt;
@@ -42,5 +42,6 @@ protected:
     VymModel *model;
     QString tmpDir; 
     QString inputFile;
+    QString htmldata;
 }; 
 #endif
