@@ -599,8 +599,12 @@ bool parseVYMHandler::readOOAttr (const QXmlAttributes& a)
 		return false;   // Couldn't read rotation
 	}           
 
-        if (!a.value( "uuid").isEmpty() && loadMode!=ImportAdd) //FIXME-2 Workaround for creating duplicate UUIDs while pasting
-            lastMI->setUuid (a.value( "uuid") );
+        if (!a.value( "uuid").isEmpty() )  
+        {
+            // While pasting, check for existing UUID
+            if (loadMode!=ImportAdd && !model->findUuid(a.value( "uuid")))
+                lastMI->setUuid (a.value( "uuid") );
+        }
     }
     return true;    
 }
